Identifier

Struct Identifier 

pub struct Identifier { /* private fields */ }
The ELF file identifier

This is the first piece of information decoded when reading an ELF file. It contains critical information necessary for the successful parsing of the rest of the file