ProgramHeader

Struct ProgramHeader 

pub struct ProgramHeader { /* private fields */ }
Program headers describe segments comprised of zero or more sections which are loaded into memory in order to construct a process image

Implementations

Source

impl ProgramHeader

pub fn program_header_type(&self) -> ProgramHeaderType

Returns a SectionType describing the purpose of the section

pub fn flags(&self) -> ProgramHeaderFlags

Returns the sections flags

pub fn alignment(&self) -> Option<usize>

Returns the sections alignment

If no alignment is required, returns None

pub fn virtual_address(&self) -> usize

Returns the virtual address at which the first byte of the segment resides in memory

pub fn physical_address(&self) -> usize

Returns the segments physical address

pub fn file_size(&self) -> usize

Returns the number of bytes the segment occupies in the file image

pub fn memory_size(&self) -> usize

Returns the number of bytes the segment occupies in the memory image