SectionHeader

Struct SectionHeader 

pub struct SectionHeader { /* private fields */ }
Describes the location and the contents of an Elf section

Implementations

Source

impl SectionHeader

pub fn section_type(&self) -> SectionType

Returns a SectionType describing the purpose of the section

pub fn flags(&self) -> SectionFlags

Returns the sections flags

pub fn address(&self) -> usize

Returns the address at which the first byte of the section will appear in a memory image, or zero if it does not

pub fn alignment(&self) -> Option<usize>

Returns the sections address alignment, or None if it does not require alignment

pub fn entry_size(&self) -> Option<usize>

If the section contains a table of fixed sized entries, this returns the size in bytes of each entry, or None otherwise

pub fn info(&self) -> usize

Returns the extra info field of the section. The interpretation of this field is dependent on the sections type