pub struct ProgramHeader { /* private fields */ }Expand description
Program headers describe segments comprised of zero or more sections which are loaded into memory in order to construct a process image
Implementations
Sourceimpl ProgramHeader
impl ProgramHeader
Sourcepub fn program_header_type(&self) -> ProgramHeaderType
pub fn program_header_type(&self) -> ProgramHeaderType
Returns a SectionType describing the purpose of the section
Sourcepub fn flags(&self) -> ProgramHeaderFlags
pub fn flags(&self) -> ProgramHeaderFlags
Returns the sections flags
Sourcepub fn alignment(&self) -> Option<usize>
pub fn alignment(&self) -> Option<usize>
Returns the sections alignment
If no alignment is required, returns None
Sourcepub fn virtual_address(&self) -> usize
pub fn virtual_address(&self) -> usize
Returns the virtual address at which the first byte of the segment resides in memory
Sourcepub fn physical_address(&self) -> usize
pub fn physical_address(&self) -> usize
Returns the segments physical address
Sourcepub fn file_size(&self) -> usize
pub fn file_size(&self) -> usize
Returns the number of bytes the segment occupies in the file image
Sourcepub fn memory_size(&self) -> usize
pub fn memory_size(&self) -> usize
Returns the number of bytes the segment occupies in the memory image