pub struct SectionHeader { /* private fields */ }Expand description
Describes the location and the contents of an Elf section
Implementations
Sourceimpl SectionHeader
impl SectionHeader
Sourcepub fn section_type(&self) -> SectionType
pub fn section_type(&self) -> SectionType
Returns a SectionType describing the purpose of the section
Sourcepub fn flags(&self) -> SectionFlags
pub fn flags(&self) -> SectionFlags
Returns the sections flags
Sourcepub fn address(&self) -> usize
pub fn address(&self) -> usize
Returns the address at which the first byte of the section will appear in a memory image, or zero if it does not
Sourcepub fn alignment(&self) -> Option<usize>
pub fn alignment(&self) -> Option<usize>
Returns the sections address alignment, or None if it does not require alignment
Sourcepub fn entry_size(&self) -> Option<usize>
pub fn entry_size(&self) -> Option<usize>
If the section contains a table of fixed sized entries, this returns the size in bytes of each entry, or None otherwise